#
# spec file for package nodejs10
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


###########################################################
#
#   WARNING! WARNING! WARNING! WARNING! WARNING! WARNING!
#
# This spec file is generated from a template hosted at
# https://github.com/AdamMajer/nodejs-packaging
#
###########################################################

Name:           nodejs10
Version:        10.16.3
Release:        lp151.2.6.1

%define node_version_number 10

%if %node_version_number >= 12
%define openssl_req_ver 1.1.1
%else
%if %node_version_number >= 10
%define openssl_req_ver 1.1.0
%else # node8 or older
%define openssl_req_ver 1.0.2
%endif
%endif

%bcond_with    valgrind_tests

%if 0%{?suse_version} == 1110
%define _libexecdir %{_exec_prefix}/lib
%endif

%if 0%{?suse_version} >= 1500 || 0%{?sle_version} >= 120400
%bcond_with    intree_openssl
%else
%bcond_without intree_openssl
%endif

%if 0%{suse_version} >= 1330
%bcond_with    intree_cares
%else
%bcond_without intree_cares
%endif

%if 0%{?suse_version} >= 1330
%bcond_with    intree_icu
%else
%bcond_without intree_icu
%endif

%if 0%{suse_version} >= 1550
%bcond_with    intree_nghttp2
%else
%bcond_without intree_nghttp2
%endif

%ifarch aarch64 ppc ppc64 ppc64le s390 s390x
%bcond_with    gdb
%else
%bcond_without gdb
%endif

# No binutils_gold on SLE 12 GA (aarch64).
%ifarch aarch64
%if 0%{?sle_version} >= 120100 || 0%{?is_opensuse}
%bcond_without binutils_gold
%else
%bcond_with    binutils_gold
%endif
%endif # aarch64

# No binutils_gold on all versions of SLE 12 and Leap 42 (s390x).
%ifarch s390x
%if 0%{?suse_version} > 1320
%bcond_without binutils_gold
%else
%bcond_with    binutils_gold
%endif
%endif # s390x

%ifarch s390
%bcond_with    binutils_gold
%endif

%ifnarch aarch64 s390x s390
%bcond_without binutils_gold
%endif

%define git_node 0

Summary:        Evented I/O for V8 JavaScript
License:        MIT
Group:          Development/Languages/NodeJS
Url:            https://nodejs.org
Source:         https://nodejs.org/dist/v%{version}/node-v%{version}.tar.xz
Source1:        https://nodejs.org/dist/v%{version}/SHASUMS256.txt
Source2:        https://nodejs.org/dist/v%{version}/SHASUMS256.txt.sig
Source3:        nodejs.keyring
# Only required to run unit tests in NodeJS 10+ 
Source10:       update_npm_tarball.sh 
Source11:       node_modules.tar.xz
Source20:       bash_output_helper.bash

## Patches not distribution specific
Patch3:         fix_ci_tests.patch
Patch7:         manual_configure.patch
Patch11:        valgrind_fixes.patch

Patch31:        CVE-2019-13173.patch

## Patches specific to SUSE and openSUSE
# PATCH-FIX-OPENSUSE -- set correct path for dtrace if it is built
Patch101:       nodejs-libpath.patch
# PATCH-FIX-UPSTREAM -- use custom addon.gypi by default instead of
# downloading node source
Patch102:       node-gyp-addon-gypi.patch
# PATCH-FIX-SLE -- configure script uses Python check_output method
# which isn't included in Python 2.6 (used in SLE 11).
Patch103:       nodejs-sle11-python26-check_output.patch
# PATCH-FIX-OPENSUSE -- install user global npm packages to /usr/local
# instead of /usr
Patch104:       npm_search_paths.patch
Patch105:       skip_test_on_lowmem.patch

Patch120:       flaky_test_rerun.patch

# Use versioned binaries and paths
Patch200:       versioned.patch

%if 0%{with binutils_gold}
BuildRequires:  binutils-gold
%endif

# Node.js 4/6/7 requires GCC 4.8.5+.
#
# For Node.js 8.x, upstream requires GCC 4.9.4+, as GCC 4.8 may have
# slightly buggy C++11 support: https://github.com/nodejs/node/pull/13466
#
# If the default compiler is not supported, use the most recent compiler
# version available.
%if 0%{?suse_version} == 1110
# GCC 5 is only available in the SUSE:SLE-11:SP4:Update repository (SDK).
%if %node_version_number >= 8
BuildRequires:  gcc5-c++
%define cc_exec  gcc-5
%define cpp_exec g++-5
%else
BuildRequires:  gcc48-c++
%define cc_exec  gcc-4.8
%define cpp_exec g++-4.8
%endif # node >= 8
%endif # sles == 11

# Use GCC 7, since it is in SLE-12:Update
%if %node_version_number >= 8 && 0%{?suse_version} == 1315
BuildRequires:  gcc7-c++
%define cc_exec  gcc-7
%define cpp_exec g++-7
%endif # node >= 8 and sle == 12

# No special version defined, use default.
%if ! 0%{?cc_exec:1}
BuildRequires:  gcc-c++
%endif

BuildRequires:  fdupes
BuildRequires:  pkg-config
BuildRequires:  procps
BuildRequires:  xz
BuildRequires:  zlib-devel
%if 0%{?suse_version} >= 1500
BuildRequires:  python2
%else
BuildRequires:  python
%endif

%if 0%{?suse_version} >= 1500 && %{node_version_number} >= 10
BuildRequires:  group(nobody)
BuildRequires:  user(nobody)
%endif

%if ! 0%{with intree_openssl}

%if %node_version_number >= 8
BuildRequires:  pkgconfig(openssl) >= %{openssl_req_ver}
%else # older node doesn't support OpenSSL 1.1

%if 0%{?suse_version} >= 1330
BuildRequires:  libopenssl-1_0_0-devel
%else
BuildRequires:  openssl-devel >= %{openssl_req_ver}
%endif

%endif # older node doesn't support OpenSSL 1.1
%endif # ! {with intree_openssl}

%if ! 0%{with intree_cares}
BuildRequires:  pkgconfig(libcares) >= 1.10.0
%endif

%if ! 0%{with intree_icu}
BuildRequires:  pkgconfig(icu-i18n) >= 57
%endif

%if ! 0%{with intree_nghttp2}
BuildRequires:  libnghttp2-devel >= 1.39.2
%endif

%if 0%{with valgrind_tests}
BuildRequires:  valgrind
%endif

Requires(post): update-alternatives
Requires(postun): update-alternatives
Recommends:     npm10

#we need ABI virtual provides where SONAMEs aren't enough/not present so deps
#break when binary compatibility is broken
%global nodejs_abi 10.0
Provides:       nodejs(abi) = %{nodejs_abi}

#this corresponds to the "engine" requirement in package.json
Provides:       nodejs(engine) = %{version}

# Multiple versions of NodeJS can be installed at a time, but
# to properly allow correct version execution from 3rd party
# npm software, `env node` requires further help than only
# update-alternatives can provide.
Provides:       nodejs = %{version}
Requires:       nodejs-common

# For SLE11, to be able to use the certificate store we need to have properly
# symlinked certificates. The compatability symlinks are provided by the
# openssl1 library in the Security Module
%if 0%{?suse_version} == 1110
Requires:       openssl1
%endif

# Building Node.js only makes sense on V8 architectures.
ExclusiveArch:  %{ix86} x86_64 armv7hl aarch64 ppc ppc64 ppc64le s390 s390x
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Node.js is a JavaScript runtime built on Chrome's V8 JavaScript engine. Node.js
uses an event-driven, non-blocking I/O model. Node.js has a package ecosystem
provided by npm.

%package devel
Summary:        Files needed for development of NodeJS platforms
Group:          Development/Languages/NodeJS
Provides:       nodejs-devel = %{version}
Requires:       %{name} = %{version}

%description devel
This package provides development headers for Node.js.

%package -n npm10
Summary:        Package manager for Node.js
Group:          Development/Languages/NodeJS
Requires:       %{name}-devel = %{version}
Provides:       nodejs-npm = %{version}
Obsoletes:      nodejs-npm < 4.0.0
Provides:       npm = %{version}
Provides:       npm(npm) = 6.9.0
%if 0%{?suse_version} >= 1500
%if %{node_version_number} >= 10
Requires:       group(nobody)
Requires:       user(nobody)
%endif
Recommends:     python2
%else
Recommends:     python
%endif

%description -n npm10
A package manager for Node.js that allows developers to install and
publish packages to a package registry.

%package docs
Summary:        Node.js API documentation
Group:          Documentation/Other
%if 0%{?suse_version} >= 1200
# using noarch subpackage seems to break debuginfo on older releases
BuildArch:      noarch
%endif

%description docs
The API documentation for the Node.js JavaScript runtime.

%prep
%if ! %{git_node}
echo "`grep node-v%{version}.tar.xz %{S:1} | head -n1 | cut -c1-64`  %{S:0}" | sha256sum -c
%setup -q -n node-v%{version}
%else
%setup -q -n node-%{version}
%endif

%if %{node_version_number} >= 10
tar Jxvf %{SOURCE11}
%endif # node_version_number

%patch3 -p1
%if ! 0%{with intree_openssl}
%endif
%patch7 -p1
%if 0%{with valgrind_tests}
%patch11 -p1
%endif
%patch31 -p1
%patch101 -p1
%patch102 -p1
# Add check_output to configure script (not part of Python 2.6 in SLE11).
%if 0%{?suse_version} == 1110
%patch103 -p1
%endif
%patch104 -p1
%patch105 -p1
%patch120 -p1
%patch200 -p1

# abnormalities from patching
find -name configure.js.orig -delete

%build
# normalize shebang
find -name \*.py -perm -1 -type f -exec sed -i '1 s,^#!\s\?/usr/bin/env python$,#!/usr/bin/python,' {} +
find deps/npm -type f -exec sed -i '1 s,^#!\s\?/usr/bin/env node$,#!/usr/bin/node%{node_version_number},' {} +
find deps/npm -type f -exec sed -i '1 s,^#!\s\?/usr/bin/env \(bash\|sh\)\?$,#!/bin/bash,' {} +

. %{SOURCE20}
# Make sure nothing gets included from bundled deps:
# We only delete the source and header files, because
# the remaining build scripts are still used.
%if ! 0%{with intree_openssl}
find deps/openssl -name *.[ch] -delete
%endif

%if ! 0%{with intree_icu}
rm -rf deps/icu-small
%endif

%if ! 0%{with intree_cares}
find deps/cares -name *.[ch] -delete
%endif

find deps/zlib -name *.[ch] -delete

# Annoying, over-repetitive patch updated just because lines in
# documentation changes every version.
find -name *.md.orig -delete

# percent-configure pulls in something that confuses node's configure
# script, so we'll do it thus:
export CFLAGS="%{optflags}"
export CXXFLAGS="%{optflags} -Wno-class-memaccess -Wno-error=return-type"

%if 0%{?cc_exec:1}
export CC=%{?cc_exec}
export CXX=%{?cpp_exec}
%endif

# Node.js 4.x does not include the ICU database in the source tarball.
%define has_small_icu %(test -d "deps/icu-small" && echo 1 || echo 0)

./configure \
    --prefix=%{_prefix} \
%if %{node_version_number} >= 12
    --enable-lto \
%endif
%if ! 0%{with intree_openssl}
    --shared-openssl \
%endif
    --shared-zlib \
%if ! 0%{with intree_cares}
    --shared-cares \
%endif
%if ! 0%{with intree_icu}
    --with-intl=system-icu \
%else
%if %{has_small_icu}
    --with-intl=small-icu \
    --with-icu-source=deps/icu-small \
%endif
%endif
%if ! 0%{with intree_nghttp2}
    --shared-nghttp2 \
%endif
%if 0%{with gdb}
    --gdb \
%endif
    --without-dtrace \
    --openssl-use-def-ca-store

decoupled_cmd make %{?_smp_mflags}

# Fix documentation permissions
find doc/api -type f -exec chmod 0644 {} +

%install
. %{SOURCE20}

%if 0%{?cc_exec:1}
export CC=%{?cc_exec}
export CXX=%{?cpp_exec}
%endif

decoupled_cmd %make_install %{?_smp_mflags}
rm %{buildroot}%{_datadir}/doc/node/gdbinit
rm -f %{buildroot}%{_datadir}/doc/node/lldbinit
rm -f %{buildroot}%{_datadir}/doc/node/lldb_commands.py

# remove .bak files, if any
find %{buildroot} -name \*.bak -print -delete

# npm/npx man page
install -D -m 644 deps/npm/man/man1/npm.1 %{buildroot}%{_mandir}/man1/npm%{node_version_number}.1
%if %{node_version_number} >= 8
install -D -m 644 deps/npm/man/man1/npx.1 %{buildroot}%{_mandir}/man1/npx%{node_version_number}.1
%endif

#node-gyp needs common.gypi too
install -D -m 644 common.gypi \
	%{buildroot}%{_libdir}/node_modules/npm%{node_version_number}/node_modules/node-gyp/common.gypi
#       %%{buildroot}%%{_datadir}/node/common.gypi
# install addon-rpm.gypi
install -D -m 644 addon-rpm.gypi \
       %{buildroot}%{_libdir}/node_modules/npm%{node_version_number}/node_modules/node-gyp/addon-rpm.gypi

# clean
# hidden files and directories
find %{buildroot}%{_libdir}/node_modules/npm%{node_version_number} -name ".*" -exec rm -Rf -- {} +
# windows stuff
find %{buildroot}%{_libdir}/node_modules/npm%{node_version_number} -name "*.bat" -delete
find %{buildroot}%{_libdir}/node_modules/npm%{node_version_number} -name "*.cmd" -delete
# build stuff
find %{buildroot}%{_libdir}/node_modules/npm%{node_version_number} -name "Makefile" -delete
rm -rf %{buildroot}%{_libdir}/node_modules/npm%{node_version_number}/{test,scripts}
find %{buildroot}%{_libdir}/node_modules/npm%{node_version_number}/node_modules -name "*.sh" -delete
rm -rf %{buildroot}%{_libdir}/node_modules/npm%{node_version_number}/node_modules/node-gyp/src
# remove examples/tests/benchmark stuff
find %{buildroot}%{_libdir}/node_modules/npm%{node_version_number}/node_modules -name "example*" -exec rm -Rf -- {} +
find %{buildroot}%{_libdir}/node_modules/npm%{node_version_number}/node_modules -name "*_test.*" -delete
find %{buildroot}%{_libdir}/node_modules/npm%{node_version_number}/node_modules -type d -name "benchmark" -exec rm -Rf -- {} +

# fix permissions
chmod 0755 %{buildroot}%{_libdir}/node_modules/npm%{node_version_number}/bin/np*-cli.js
chmod 0755 %{buildroot}%{_libdir}/node_modules/npm%{node_version_number}/bin/node-gyp-bin/node-gyp
chmod 0755 %{buildroot}%{_libdir}/node_modules/npm%{node_version_number}/node_modules/node-gyp/bin/node-gyp.js
%if %{node_version_number} >= 8
chmod 0755 %{buildroot}%{_libdir}/node_modules/npm%{node_version_number}/node_modules/npm-lifecycle/node-gyp-bin/node-gyp
%endif

# browser.js is useless for npm cli
find %{buildroot}%{_libdir}/node_modules/npm%{node_version_number} -name "browser.js" -delete

# file duplicates
%fdupes %{buildroot}%{_libdir}/node_modules/npm%{node_version_number}
%fdupes %{buildroot}%{_includedir}/node%{node_version_number}

# Update alternatives
mkdir -p %{buildroot}%{_sysconfdir}/alternatives
ln -s -f node-default     %{buildroot}%{_sysconfdir}/alternatives/node-default
ln -s -f node.1%{ext_man} %{buildroot}%{_sysconfdir}/alternatives/node.1%{ext_man}
ln -s -f npm-default      %{buildroot}%{_sysconfdir}/alternatives/npm-default
ln -s -f npm.1%{ext_man}  %{buildroot}%{_sysconfdir}/alternatives/npm.1%{ext_man}
ln -s %{_sysconfdir}/alternatives/node-default         %{buildroot}%{_bindir}/node-default
ln -s %{_sysconfdir}/alternatives/node.1%{ext_man}     %{buildroot}%{_mandir}/man1/node.1%{ext_man}
ln -s %{_sysconfdir}/alternatives/npm-default          %{buildroot}%{_bindir}/npm-default
ln -s %{_sysconfdir}/alternatives/npm.1%{ext_man}      %{buildroot}%{_mandir}/man1/npm.1%{ext_man}
%if %{node_version_number} >= 8
ln -s -f npx-default      %{buildroot}%{_sysconfdir}/alternatives/npx-default
ln -s -f npx.1%{ext_man}  %{buildroot}%{_sysconfdir}/alternatives/npx.1%{ext_man}
ln -s %{_sysconfdir}/alternatives/npx-default          %{buildroot}%{_bindir}/npx-default
ln -s %{_sysconfdir}/alternatives/npx.1%{ext_man}      %{buildroot}%{_mandir}/man1/npx.1%{ext_man}
%endif

# We need to own license directory on old versions of SLE
%if 0%{?suse_version} < 1500
mkdir -p %{buildroot}%{_defaultlicensedir}
%endif

%check
%if 0%{?cc_exec:1}
export CC=%{?cc_exec}
export CXX=%{?cpp_exec}
%endif

ln addon-rpm.gypi deps/npm/node_modules/node-gyp/addon-rpm.gypi
# Tarball doesn't have eslint package distributed, so disable some tests
find test -name \*-eslint-\* -print -delete
# No documentation is generated, don't bother checking it
rm -f test/doctool/test-make-doc.js
# DNS lookup doesn't work in build root
rm -f test/parallel/test-dns-cancel-reverse-lookup.js \
      test/parallel/test-dns-resolveany.js
# multicast test fail since no socket?
rm -f test/parallel/test-dgram-membership.js
# Run CI tests
%if 0%{with valgrind_tests}
# valgrind may have false positives, so do not fail on these by default
make test-valgrind ||:
%endif
make test-ci

%files
%defattr(-, root, root)
%license LICENSE
%doc AUTHORS *.md
%doc deps/v8/tools/gdbinit
%dir %{_libdir}/node_modules
%{_bindir}/node%{node_version_number}
%{_mandir}/man1/node%{node_version_number}.1%{ext_man}
%ghost %{_bindir}/node-default
%ghost %{_mandir}/man1/node.1%{ext_man}
%ghost %{_sysconfdir}/alternatives/node-default
%ghost %{_sysconfdir}/alternatives/node.1%{ext_man}
%exclude %{_libdir}/node_modules/npm%{node_version_number}
# We need to own directory on old versions of SLE
%if 0%{?suse_version} < 1500
%dir %{_defaultlicensedir}
%endif

%files -n npm%{node_version_number}
%defattr(-, root, root)
%{_bindir}/npm%{node_version_number}
%{_libdir}/node_modules/npm%{node_version_number}
%{_mandir}/man1/npm%{node_version_number}.1%{ext_man}
%ghost %{_bindir}/npm-default
%ghost %{_mandir}/man1/npm.1%{ext_man}
%ghost %{_sysconfdir}/alternatives/npm-default
%ghost %{_sysconfdir}/alternatives/npm.1%{ext_man}

%if %{node_version_number} >= 8
%{_bindir}/npx%{node_version_number}
%{_mandir}/man1/npx%{node_version_number}.1%{ext_man}
%ghost %{_bindir}/npx-default
%ghost %{_mandir}/man1/npx.1%{ext_man}
%ghost %{_sysconfdir}/alternatives/npx-default
%ghost %{_sysconfdir}/alternatives/npx.1%{ext_man}
%endif

%files devel
%defattr(-, root, root)
%{_includedir}/node%{node_version_number}
%dir %{_datadir}/systemtap
%dir %{_datadir}/systemtap/tapset
%{_datadir}/systemtap/tapset/node%{node_version_number}.stp

%files docs
%defattr(-,root,root)
%doc doc/api

%pre
# remove files that are no longer owned but provided by update-alternatives
if ! [ -L %{_mandir}/man1/node.1%{ext_man} ]; then
    rm -f %{_mandir}/man1/node.1%{ext_man}
fi

%post
update-alternatives \
        --install %{_bindir}/node-default node-default %{_bindir}/node%{node_version_number} %{node_version_number} \
        --slave %{_mandir}/man1/node.1%{ext_man} node.1%{ext_man} %{_mandir}/man1/node%{node_version_number}.1%{ext_man}

%postun
if [ ! -f %{_bindir}/node%{node_version_number} ] ; then
    update-alternatives --remove node-default %{_bindir}/node%{node_version_number}
fi

%pre -n npm%{node_version_number}
# remove files that are no longer owned but provided by update-alternatives
if ! [ -L %{_mandir}/man1/npm.1%{ext_man} ]; then
    rm -f %{_mandir}/man1/npm.1%{ext_man}
fi

%post -n npm%{node_version_number}
update-alternatives \
        --install %{_bindir}/npm-default npm-default %{_bindir}/npm%{node_version_number} %{node_version_number} \
        --slave %{_mandir}/man1/npm.1%{ext_man} npm.1%{ext_man} %{_mandir}/man1/npm%{node_version_number}.1%{ext_man}
%if %{node_version_number} >= 8
update-alternatives \
        --install %{_bindir}/npx-default npx-default %{_bindir}/npx%{node_version_number} %{node_version_number} \
        --slave %{_mandir}/man1/npx.1%{ext_man} npx.1%{ext_man} %{_mandir}/man1/npx%{node_version_number}.1%{ext_man}
%endif

%postun -n npm%{node_version_number}
if [ ! -f %{_bindir}/npm%{node_version_number} ] ; then
    update-alternatives --remove npm-default %{_bindir}/npm%{node_version_number}
fi
%if %{node_version_number} >= 8
if [ ! -f %{_bindir}/npx%{node_version_number} ] ; then
    update-alternatives --remove npx-default %{_bindir}/npx%{node_version_number}
fi
%endif

%changelog
* Fri Aug 16 2019 Adam Majer <adam.majer@suse.de>
- Update to 10.16.3:
  Security update regarding HTTP/2 Denial of Service vulnerabilities
  For details see,
  https://github.com/nodejs/node/blob/master/doc/changelogs/CHANGELOG_V12.md#12.8.1
  https://github.com/Netflix/security-bulletins/blob/master/advisories/third-party/2019-002.md
  (CVE-2019-9511, CVE-2019-9512, CVE-2019-9513, CVE-2019-9514,
  bsc#1146091, bsc#1146099, bsc#1146094, bsc#1146095,
  CVE-2019-9515, CVE-2019-9516, CVE-2019-9517, CVE-2019-9518,
  bsc#1146100, bsc#1146090, bsc#1146097, bsc#1146093)
- Changes in 10.16.2:
  * fix OpenSSL upgrade to 1.1.1c that causes intermittent hangs in
    machines that have low entropy.
* Thu Aug  1 2019 Adam Majer <adam.majer@suse.de>
- New upstream LTS version 10.16.1
  * deps: upgrade openssl sources to 1.1.1c (for SLE-12 based systems)
  * stream: do not unconditionally call _read() on resume()
  * worker: fix nullptr deref after MessagePort deser failure
* Mon Jul 29 2019 Adam Majer <adam.majer@suse.de>
- CVE-2019-13173.patch: fix potential file overwrite via hardlink
  in fstream.DirWriter() function (bsc#1140290, CVE-2019-13173)
* Wed May 29 2019 Adam Majer <adam.majer@suse.de>
- New upstream LTS version 10.16.0
  * deps:
    + upgrade npm to 6.9.0
    + upgrade openssl sources to 1.1.1b (for SLE-12 based systems)
    + upgrade libuv to 1.28.0 (for SLE-12 based systems)
    + upgrade to libuv 1.28.0
  * events: add once method to use promises with EventEmitter
  * n-api: mark thread-safe function as stable
  * repl: support top-level for-await-of
  * zlib: add brotli support
- openssl_1_1_1.patch: dropped, no longer needed
- fix_ci_tests.patch: drop onion handling in DNS, since this depends
  on 3rd party library
- versioned.patch: refreshed
* Mon May  6 2019 Adam Majer <adam.majer@suse.de>
- openssl_1_1_1.patch: backport fixes for OpenSSL 1.1.1 (bsc#1134208)
- Require user/group nobody for npm
* Sun Apr  7 2019 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Add _constraints file to avoid OOM errors
* Fri Apr  5 2019 Adam Majer <adam.majer@suse.de>
- flaky_test_rerun.patch: rework patch to account for tests that
  end with an exception and are not actually re-run...
* Wed Mar  6 2019 Adam Majer <adam.majer@suse.de>
- New upstream LTS version 10.15.3
  * http: fix error check in Execute()
  * stream: fix end-of-stream for HTTP/2
- fix_ci_tests.patch: refreshed
* Thu Feb 28 2019 Adam Majer <adam.majer@suse.de>
- New upstream LTS version 10.15.2
  * http: Further prevention of "Slowloris" attacks on HTTP and HTTPS
  connections by consistently applying the receive timeout set by
  server.headersTimeout to connections in keep-alive mode.
  (CVE-2019-5737, bsc#1127532)
* Fri Feb  1 2019 adam.majer@suse.de
- nodejs.keyring: update keyring to today's list as per
  https://github.com/nodejs/node
* Fri Feb  1 2019 adam.majer@suse.de
- New upstream LTS version 10.15.1
  * tls: throw if protocol too long
- fix_ci_tests.patch: refreshed
* Mon Jan  7 2019 adam.majer@suse.de
- New upstream LTS version 10.15.0
  (still bsc#1112438, FATE#326776, FATE#326919):
  * cli: add --max-http-header-size flag
  * http: add maxHeaderSize property
- Changes in version 10.14.2
  * deps: upgrade to c-ares v1.15.0
  * child_process: handle undefined/null for fork() args
  * http2: make Http2Settings constructors delegate
  * os: fix memory leak in userInfo()
- fix_ci_tests.patch: refreshed
* Thu Dec  6 2018 adam.majer@suse.de
- New upstream LTS version 10.14.1 (still bsc#1112438, FATE#326776):
  * deps: Upgrade to OpenSSL 1.1.0j, fixing
    + Timing vulnerability in DSA signature generation
    (bsc#1113652, CVE-2018-0734)
    + Timing vulnerability in ECDSA signature generation
    (bsc#1113651, CVE-2018-0735)
  * http:
    + Headers received by HTTP servers must not exceed 8192 bytes
    in total to prevent possible Denial of Service attacks.
    (bsc#1117626, CVE-2018-12121)
    + A timeout of 40 seconds now applies to servers receiving
    HTTP headers. This value can be adjusted with
    server.headersTimeout. Where headers are not completely
    received within this period, the socket is destroyed on
    the next received chunk. In conjunction
    with server.setTimeout(), this aids in protecting against
    excessive resource retention and possible Denial of Service.
    (bsc#1117627, CVE-2018-12122)
  * url: Fix a bug that would allow a hostname being spoofed when
    parsing URLs with url.parse() with the 'javascript:' protocol.
    (bsc#1117629, CVE-2018-12123)
* Mon Nov 26 2018 adam.majer@suse.de
- flaky_test_rerun.patch: Rerun failing tests in case of flakiness
* Tue Oct 30 2018 adam.majer@suse.de
- New upstream LTS 10.13.0: (bsc#1112438, FATE#326776)
  * buffer: fix crash for invalid index types
  * deps: fix wrong default for v8 handle zapping
- env_shebang.patch: dropped
- skip_test_on_lowmem.patch: skip some build tests on low-memory
  build machines
* Tue Oct 16 2018 adam.majer@suse.de
- node-gyp-addon-gypi.patch: patch fixes (bsc#1094617)
* Sun Oct 14 2018 adam.majer@suse.de
- add support for runnign valgrind tests during check, disabled
  by default
- valgrind_fixes.patch: valgrind fixes
* Thu Oct 11 2018 adam.majer@suse.de
- New upstream version 10.12.0:
  * cli:
    + The options parser now normalizes _ to - in all multi-word
    command-line flags, e.g. --no_warnings == --no-warnings
    + Added bash completion for the node binary.
    To generate a bash completion script, run node --completion-bash.
  * crypto:
    + Added support for PEM-level encryption.
    + Added an API asymmetric key pair generation.
  * fs: Added a recursive option to fs.mkdir and fs.mkdirSync.
  * http2:
    + Added support for the ORIGIN frame.
    + Added a 'ping' event to Http2Session that is emitted whenever
    a non-ack PING is received.
    + Updated nghttp2 to 1.34.0. This adds RFC 8441 extended
    connect protocol support to allow use of WebSockets over HTTP/2.
  * module: Added module.createRequireFromPath(filename). This
    new method can be used to create a custom require function that
    will resolve modules relative to the filename path.
  * process: Added a 'multipleResolves' process event that
    is emitted whenever a Promise is attempted to be resolved
    multiple times, e.g. if the resolve and reject functions are
    both called in a Promise executor.
  * url: Added url.fileURLToPath(url) and url.pathToFileURL(path)
  * util:
    + Added the sorted option to util.inspect()
    + Added support for BigInt numbers in util.format()
  * V8 API: A number of V8 C++ APIs have been marked as deprecated
  * Workers:
    + Added debugging support for Workers via DevTools protocol
    + The public inspector module is now enabled in Workers.
- fix_ci_tests.patch: updated
* Fri Oct  5 2018 adam.majer@suse.de
- fix_ci_tests.patch: fix unit tests
* Tue Sep 25 2018 adam.majer@suse.de
- New upstream version 10.11.0:
  * fs: Fixed fsPromises.readdir withFileTypes.
  * http2: Added http2stream.endAfterHeaders property.
  * util: Added util.types.isBoxedPrimitive(value).
- 21257.diff: drop the patch in favour of running node compilation
  by redirecting stdio through a FIFO
- versioned.patch: refreshed
- fix_ci_tests.patch: explicity disable doc target in unit tests
* Wed Sep 12 2018 adam.majer@suse.de
- New upstream version 10.10.0:
  * child_process: TypedArray and DataView values are now accepted as
    input by execFileSync and spawnSync.
  * coverage: Native V8 code coverage information can now be output to
    disk by setting the environment variable NODE_V8_COVERAGE
    to a directory.
  * deps: The bundled npm was upgraded to version 6.4.1.
  * fs:
    + The methods fs.read, fs.readSync, fs.write, fs.writeSync,
    fs.writeFile and fs.writeFileSync now all accept TypedArray and
    DataView objects.
    + A new boolean option, withFileTypes, can be passed to
    fs.readdir and fs.readdirSync. If set to true, the methods
    return an array of directory entries. These are objects that
    can be used to determine the type of each entry and filter them
    based on that without calling fs.stat.
  * http2: The http2 module is no longer experimental.
  * os: Added two new methods: os.getPriority and os.setPriority,
    allowing to manipulate the scheduling priority of processes.
  * process: Added process.allowedNodeEnvironmentFlags. This object
    can be used to programmatically validate and list flags that
    are allowed in the NODE_OPTIONS environment variable.
  * src: Deprecated option variables in public C++ API.
  * vm: Added vm.compileFunction, a method to create new JavaScript
    functions from a source body, with options similar to those of
    the other vm methods.
- 21257.diff: refresh patch (and make it forward apply)
- versioned.patch, env_shebang.path: refreshed
* Mon Sep 10 2018 adam.majer@suse.de
- 21257.diff: Revert an upstream revert that resulted that stdout
  remaining O_NONBLOCK during build process. This resulted in
  build failures.
* Mon Aug 20 2018 adam.majer@suse.de
- New upstream release 10.9.0:
  * buffer:
    + Fix out-of-bounds (OOB) write in Buffer.write() for
    UCS-2 encoding (CVE-2018-12115, bsc#1105019)
    + Fix unintentional exposure of uninitialized memory in
    Buffer.alloc() (bsc#1105018, CVE-2018-7166)
  * deps: Upgrade to OpenSSL 1.0.2p, fixing:
    + Client DoS due to large DH parameter
    (CVE-2018-0732, bsc#1097158)
    + ECDSA key extraction via local side-channel
  * http: http.get() and http.request() (and https variants)
    now accept three arguments to allow for a URL and options object
* Mon Aug 13 2018 adam.majer@suse.de
- New upstream release 10.8.0:
  * deps: upgrade npm to 6.2.0
- Changes in version 10.7.0:
  * console: The console.timeLog() method has been implemented.
  * http: Added support for passing both timeout and agent options
    to http.request.
  * inspector: Expose the original console API in
    require('inspector').console.
  * napi: Added experimental support for functions dealing with
    bigint numbers.
  * process:
    + The process.hrtime.bigint() method has been implemented.
    + Added the --title command line argument to set the process
    title on startup.
  * trace_events: Added process_name metadata.
- icu_small_grouping.patch: upstreamed
- versioned.patch, env_shebang.patch: refreshed
- update Jan's description changes for grammar and merge into git
* Sun Jul 29 2018 jengelh@inai.de
- Ensure neutrality of description.
- Use %%make_install.
* Thu Jul  5 2018 adam.majer@suse.de
- New upstream release 10.6.0:
  * dns: An experimental promisified version of the dns module is
    now available. Give it a try with require('dns').promises.
  * fs: fs.lchown has been undeprecated now that libuv supports it.
  * lib: Atomics.wake is being renamed to Atomics.notify in the
    ECMAScript specification (reference). Since Node.js now has
    experimental support for worker threads, we are being proactive
    and added a notify alias, while emitting a warning if wake is used.
  * n-api: Add API for asynchronous functions.
  * util: util.inspect is now able to return a result instead of
    throwing when the maximum call stack size is exceeded during
    inspection.
  * vm: Add script.createCachedData(). This API replaces the
    produceCachedData option of the Script constructor that is
    now deprecated
  * worker: Support for relative paths has been added to the Worker
    constructor. Paths are interpreted relative to the current
    working directory.
- versioned.patch: refreshed
* Fri Jun 22 2018 adam.majer@suse.de
- New upstream release 10.5.0:
  * crypto: Support for crypto.scrypt() has been added
  * fs:
    + APIs that take mode as arguments no longer throw on values
    larger than 0o777
    + BigInt support has been added to fs.stat and fs.watchFile
    + Fix crashes in closed event watchers.
  * worker_threads: multi-threading has been added behind the
  - -experimental-worker flag in the worker_threads module.
    This feature is *experimental* and may receive breaking changes
    at any time.
- npm_search_paths.patch: Fix typo causing npm to not work
* Wed Jun 13 2018 adam.majer@suse.de
- New upstream release 10.4.1:
  * Fixes memory exhaustion DoS: Fixes a bug that increases the
    memory consumed when reading from the network into JavaScript
    using the net.Socket object directly as a stream
    (CVE-2018-7164, bsc#1097537)
  * http2:
    + Fixes Denial of Service vulnerability by updating the
    http2 implementation to not crash under certain circumstances
    during cleanup (CVE-2018-7161, bsc#1097404)
    + Unbundled nghttp2 to fix Denial of Service vulnerability
    (CVE-2018-1000168, bsc#1097401)
  * tls: Fixes Denial of Service vulnerability by updating the TLS
    implementation to not crash upon receiving
    (CVE-2018-7162, bsc#1097538)
* Mon Jun 11 2018 adam.majer@suse.de
- New upstream release 10.4.0:
  * deps: update V8 to 6.7.288.43
  * stream: ensure Stream.pipeline re-throws errors without callback
- Changes in version 10.3.0:
  * deps: upgrade npm to 6.1.0
  * fs: fix reads with pos > 4GB
  * net: new option to allow IPC servers to be readable and writable
    by all users
  * stream: fix removeAllListeners() for Stream.Readable to work as
    expected when no arguments are passed
  npm_search_paths.patch: no longer override explicitly prefixed etc/
  versioned.patch, env_shebang.patch: refreshed
* Thu May 24 2018 adam.majer@suse.de
- New upstream release 10.2.0:
  * addons: Fixed a memory leak for users of AsyncResource and N-API.
  * assert: The error parameter of assert.throws() can now be
    an object containing regular expressions.
  * crypto: The authTagLength option has been made more flexible.
  * esm: Builtin modules now provide named exports in ES6 modules.
  * http: Handling of close and aborted events has been made more
    consistent.
  * module: add --preserve-symlinks-main
  * timers: timeout.refresh() has been added to the public API.
- fix_ci_tests.patch: refreshed
- versioned.patch: refreshed
* Wed May 23 2018 adam.majer@suse.de
- use gcc7 for SLE12
- versioned.patch: set node version in environment to 10
- manual_configure.patch: configure nghttp2 correctly
- icu_small_grouping.patch: prevents undefined behaviour possibility
* Fri May 11 2018 adam.majer@suse.de
- New upstream release 10.1.0:
  * console: make console.table() use colored inspect
  * fs: move fs/promises to fs.promises
  * http: added aborted property to request
  * n-api: initialize a module via a special symbol
  * src: add public API to expose the main V8 Platform
- Changes in version 10.0.0:
  * Assert:
    + Calling assert.fail() with more than one argument is deprecated.
    + Calling assert.ok() with no arguments will now throw.
    + Calling assert.ifError() will now throw with any argument
    other than undefined or null. Previously the method would throw
    with any truthy value.
  * Async_hooks:
    + Older experimental async_hooks APIs have been removed.
  * Buffer:
    + Uses of new Buffer() and Buffer() outside of the node_modules
    directory will now emit a runtime deprecation warning.
    + Buffer.isEncoding() now returns undefined for falsy values,
    including an empty string.
    + Buffer.fill() will throw if an attempt is made to fill with
    an empty Buffer.
  * Child Process: Undefined properties of env are ignored.
  * console: console.table() method has been added.
  * crypto:
    + The crypto.createCipher() and crypto.createDecipher() methods
    have been deprecated. Please use crypto.createCipheriv() and
    crypto.createDecipheriv() instead.
    + The decipher.finaltol() method has been deprecated.
    + The crypto.DEFAULT_ENCODING property has been deprecated.
    + The ECDH.convertKey() method has been added.
    + The crypto.fips property has been deprecated.
  * deps:
    + V8 has been updated to 6.6
    + npm upgraded to 5.8.0
  * EventEmitter:
    + The EventEmitter.prototype.off() method has been added as
    an alias for EventEmitter.prototype.removeListener().
  * File System:
    + The fs/promises API provides experimental promisified
    versions of the fs functions.
    + Invalid path errors are now thrown synchronously.
    + fs.readFile() method now partitions reads to avoid thread
    pool exhaustion.
  * http:
    + Processing of HTTP Status codes 100, 102-199 has been improved.
    + Multi-byte characters in URL paths are now forbidden.
  * N-API: The n-api is no longer experimental.
  * net: The 'close' event will be emitted after 'end'.
  * perf_hooks:
    + The PerformanceObserver class is now an AsyncResource and can
    be monitored using async_hooks.
    + Trace events are now emitted for performance events.
    + The performance API has been simplified.
    + Performance milestone marks will be emitted as trace events.
  * process:
    + Using non-string values for process.env is deprecated.
    + The process.assert() method is deprecated.
  * repl:
    + REPL now experimentally supports top-level await when using
    the --experimental-repl-await flag.
    + The previously deprecated "magic mode" has been removed.
    + The previously deprecated NODE_REPL_HISTORY_FILE environment
    variable has been removed.
    + Proxy objects are shown as Proxy objects when inspected.
  * streams:
    + The 'readable' event is now always deferred with nextTick.
    + A new pipeline() method has been provided for building
    end-to-data stream pipelines.
    + support for async for-await has been added to stream.Readable
  * timers: The enroll() and unenroll() methods have been deprecated
  * tls:
    + The tls.convertNPNProtocols() method has been deprecated.
    + Support for NPN (next protocol negotiation) has been dropped.
    + The ecdhCurve default is now 'auto'.
  * Trace Events:
    + A new trace_events top-level module allows trace event
    categories to be enabled/disabled at runtime.
  * URL: The WHATWG URL API is now a global.
  * Util:
    + util.types.is[…] type checks have been added.
    + Support for bigint formatting has been added to util.inspect().
- OpenSSL 1.1.0+ is required.
- versioned.patch: rebased
* Wed Apr 18 2018 adam.majer@suse.de
- New upstream release 9.11.1:
  * deps: Updated ICU to 61.1
  * fs: Emit 'ready' event for ReadStream and WriteStream
  * n-api: Bump version of n-api supported to 3
  * net: Emit 'ready' event for Socket
- versioned.patch, nodejs-libpath.patch: refreshed
* Thu Apr  5 2018 adam.majer@suse.de
- Install license with %%license, not %%doc (bsc#1082318)
* Wed Apr  4 2018 adam.majer@suse.de
- Fix some node-gyp permissions
* Tue Apr  3 2018 adam.majer@suse.de
- New upstream release 9.10.1:
  * Security fixes:
    + Fix for inspector DNS rebinding vulnerability
    (bsc#1087463, CVE-2018-7160)
    + Fix for 'path' module regular expression denial of service
    (bsc#1087459, CVE-2018-7158)
    + Reject spaces in HTTP Content-Length header values
    (bsc#1087453, CVE-2018-7159)
  * cluster: Add support for NODE_OPTIONS="--inspect"
  * crypto: Expose the public key of a certificate
  * n-api: Add napi_fatal_exception to trigger an uncaughtException
    in JavaScript
  * path: Fix regression in posix.normalize
  * stream: Improve stream creation performance
  * update bundled OpenSSL for codestreams older than SLE12:SP2
* Thu Mar 22 2018 adam.majer@suse.de
- New upstream release 9.9.0:
  * assert: From now on all error messages produced by assert in
    strict mode will produce a error diff.
  * crypto: allow passing null as IV unless required
  * fs: support as and as+ flags in stringToFlags()
  * tls: expose Finished messages in TLSSocket
  * tty: Add getColorDepth function to determine if terminal
    supports colors.
  * util: add util.inspect compact option
- Changes in version 9.8.0:
  * crypto: add cert.fingerprint256 as SHA256 fingerprint
  * http2: Fixed issues with aborted connections
  * loader: --inspect-brk now works properly for esmodules
  * src: make process.dlopen() load well-known symbol
  * trace_events: add file pattern cli option
- remove any old manpage files in %%pre from before update-alternatives
  were used to manage symlinks to these manpages.
* Fri Mar  2 2018 adam.majer@suse.de
- New upstream release 9.7.1/9.7.0:
  * deps: libuv updated to 1.19.2
  * src: Add initial support for Node.js-specific post-mortem metadata
  * timers: return value of setImmediate() now has ref() and unref()
  * util: platform-specific error codes now have string representation
- Changes in version 9.6.0:
  * async_hooks:
    + deprecate unsafe emit{Before,After}
    + rename PromiseWrap.parentId to PromiseWrap.isChainedPromise
  * deps:
    + update node-inspect to 1.11.3
    + ICU 60.2 bump
    + Introduce ScriptOrModule and HostDefinedOptions to V8
  * http: add options to http.createServer() for IncomingMessage and
    ServerReponse
  * http2: add http fallback options to .createServer
  * https: Adds the remaining options from tls.createSecureContext()
    to the string generated by Agent#getName(). This allows
    https.request() to accept the options and generate unique
    sockets appropriately.
  * inspector: --inspect-brk for es modules
  * lib: allow process kill by signal number
  * module: enable dynamic import
  * n-api: add methods to open/close callback scope
  * src: allow --perf-(basic-)?prof in NODE_OPTIONS
  * vm: add support for es modules
- gyp_to_python3.patch: attempt to add support for python3.
- fix_ci_tests.patch, versioned.patch: refreshed
* Tue Feb 13 2018 adam.majer@suse.de
- Add Recommends and BuildRequire on python2 for npm. node-gyp
  requires this old version of python for now. This is only needed
  for binary modules.
* Wed Feb  7 2018 adam.majer@suse.de
- Fix spec file typo
- Use gcc7 on Leap 42.3
* Thu Feb  1 2018 adam.majer@suse.de
- New upstream release 9.5.0:
  * cluster: add cwd to cluster.settings
  * deps: libuv upgraded to 1.19.1
  * n-api: expose n-api version in proces.versions
  * perf_hooks: add performance.clear()
  * stream: avoid writeAfterEnd()
- Changes in release 9.4.0:
  * async_hooks: deprecate AsyncHooks Sensitive API and
    runInAsyncIdScope. Neither was documented.
  * deps:
    + upgrade nghttp2 to 1.29.0
    + upgrade npm to 5.6.0
  * http2:
    + implement maxSessionMemory
    + add initial support for originSet
    + add altsvc support
    + perf_hooks integration
  * net: remove Socket.prototype.listen
  * repl: show lexically scoped vars in tab completion
  * stream:
    + remove writeableState.length and readableState.length
    + add flow and buffer properties to streams
  * util: allow windcards in NODE_DEBUG variable
  * zlib: add ArrayBuffer support
* Tue Jan 30 2018 ro@suse.de
- even on recent codestreams there is no binutils gold on s390
  only on s390x
* Wed Jan 10 2018 adam.majer@suse.de
- nodejs-sle11-python26-check_output.patch: refreshed
* Fri Dec 22 2017 adam.majer@suse.de
- Enable CI tests in %%check target
  + fix_ci_tests.patch:
  - DNS queries in buildroots are failing with EAI_AGAIN
  - disable test-module-loading-globalpaths.js - we have
    hardcoded global paths
  + versioned.patch: call versioned node binary for tests
- node-gyp-addon-gypi.patch: fix typo allowing unit tests to compile
* Fri Dec 15 2017 adam.majer@suse.de
- New upstream release 9.3.0:
  * async_hooks:
    + add trace events to async_hooks
    + add provider types for net server
  * console: console.debug can now be used outside of the inspector
  * deps:
    + upgrade libuv to 1.18.0
    + patch V8 to 6.2.414.46
  * module.builtinModules will return a list of built in modules
  * n-api: add helper for addons to get the event loop
  * process:
    + process.setUncaughtExceptionCaptureCallback can now be used
    to customize behavior for --abort-on-uncaught-exception
    + A signal handler is now able to receive the signal code that
    triggered the handler.
  * stream: writable.writableHighWaterMark and
    readable.readableHighWaterMark will return the values the
    stream object with which it was instantiated.
- Dropped 8334.diff - no longer needed
* Sat Dec  9 2017 qantas94heavy@gmail.com
- New upstream release 9.2.1:
  * buffer: buffers allocated with an invalid content will now be
    zero filled
    [ CVE-2017-15897 ]
  * deps/openssl: updated to 1.0.2n (only applies to SLE 12 SP1
    and lower) (bsc#1072322)
    [ CVE-2017-3738 CVE-2017-15896 ]
- Remove unnecessary curl BuildRequires
- Enable gold linker on s390x (TW and SLE/Leap 15)
- Build with bundled ICU if system ICU not available (only applies
  to SLE 11/12 and Leap 42.x)
* Wed Nov 29 2017 qantas94heavy@gmail.com
- Change BuildRequires from openssl-devel to libopenssl-1_0_0-devel
  due to Tumbleweed/Leap 15 change to OpenSSL 1.1.0 as default
* Thu Nov 16 2017 adam.majer@suse.de
- Update nodejs.keyring based on current Release Team as found on
  https://github.com/nodejs/node#release-team
- New upstream version 9.2.0
  * crypto: Support building with both OpenSSL 1.1.0
  * fs: fs.realpathSync.native and fs.realpath.native are now exposed
  * process: expose process.ppid
* Mon Nov 13 2017 adam.majer@suse.de
- Fix permissions of node-gyp. This should be executable to allow
  building of binary node modules.
* Fri Nov 10 2017 adam.majer@suse.de
- New upstream version 9.1.0
  * cli: NODE_OPTIONS now supports the --stack-trace-limit option.
  * http:
    + A 'connect' event handler leak has been fixed.
    + The 103 Early Hints status code is now supported.
- Changes in upstream version 9.0.0
  * async: Older experimental APIs have been removed.
  * errors: The assignment of static error codes to Node.js errors
  * child_processes: Errors are emitted on process nextTick.
  * domains: The long-deprecated .dispose() method has been removed
  * fs:
    + fs.ReadStream and fs.WriteStream classes now use destroy().
    + module callbacks are now invoked with an undefined context.
  * HTTP/1:
    + 400 Bad Request response will now be sent when parsing fails.
    + Socket timeout will be set when the socket connects.
    + A bug causing the request 'error' event to fire twice is fixed.
    + HTTP clients may now use generic Duplex streams in addition
    to net.Socket.
  * intl: The deprecated Intl.v8BreakIterator has been removed.
  * os: The os.EOL property is now read-only
  * timers: setTimeout() will emit a warning if the timeout is
    larger that the maximum 32-bit unsigned integer.
- .changes file trimmed to only include changes relative to 9.x
  line. If you would like to see older changes, please see
  nodejs8 package.
- icu59.patch 0f3e69db.patch: removed empty patches
